@@ -8,8 +8,8 @@ Prints out the current environment
 
 sub bi_env
 {
-	foreach my $key (keys %ENV) {
-		print_out("$key=$ENV{$key}\n");
+	foreach my $key (sort keys %ENV) {
+		Psh::Util::print_out("$key=$ENV{$key}\n");
 	}
 	return undef;
 }
