@@ -3,10 +3,11 @@ package Psh::OS;
 use strict;
 use vars qw($VERSION $AUTOLOAD $ospackage);
 use Carp 'croak';
+use Cwd;
 use Config;
 use File::Spec;
 
-$VERSION = do { my @r = (q$Revision: 1.8 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
+$VERSION = do { my @r = (q$Revision: 1.14 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
 
 $ospackage="Psh::OS::Unix";
 
@@ -20,8 +21,9 @@ sub AUTOLOAD {
 	$AUTOLOAD=~ s/.*:://;
 	no strict 'refs';
 	my $name="${ospackage}::$AUTOLOAD";
+	$name="Psh::OS::fb_$AUTOLOAD" unless ref *{$name}{CODE} eq 'CODE';
 	croak "Function `$AUTOLOAD' in Psh::OS does not exist." unless
-		ref *{"${ospackage}::$AUTOLOAD"}{CODE} eq 'CODE';
+		ref *{$name}{CODE} eq 'CODE';
 	*$AUTOLOAD=  *$name;
 	goto &$AUTOLOAD;
 }
@@ -32,12 +34,6 @@ sub AUTOLOAD {
 # If you need to override them, then modify the symbol
 # table :-)
 
-
-# Simply doing backtick eval - mainly for Prompt evaluation
-sub backtick {
-	return `@_`;
-}
-
 # recursive glob function used for **/anything glob
 sub _recursive_glob {
 	my( $pattern, $dir)= @_;
@@ -54,12 +50,22 @@ sub _recursive_glob {
 	return @result;
 }
 
+sub _escape {
+	my $text= shift;
+	if ($] >= 5.005) {
+		$text=~s/(?<!\\)([^a-zA-Z0-9\*\?])/\\$1/g;
+	} else {
+		# TODO: no escaping yet
+	}
+	return $text;
+}
+
 #
 # The Perl builtin glob STILL uses csh, furthermore it is
 # not possible to supply a base directory... so I guess this
 # is faster
 #
-sub glob {
+sub fb_glob {
 	my( $pattern, $dir) = @_;
 	my @result;
 	if( !$dir) {
@@ -78,11 +84,11 @@ sub glob {
 	# Special recursion handling for **/anything globs
 	if( $pattern=~ m:^([^\*]+/)?\*\*/(.*)$: ) {
 		my $tlen= length($dir)+1;
-		my $prefix= $1;
+		my $prefix= $1||'';
 		$pattern= $2;
 		$prefix=~ s:/$::;
 	    $dir= File::Spec->catdir($dir,$prefix);
-		$pattern=~s/(?<!\\)([^a-zA-Z0-9\*\?])/\\$1/g;
+		$pattern=_escape($pattern);
 		$pattern=~s/\*/[^\/]*/g;
 		$pattern=~s/\?/./g;
 		$pattern='[^\.]'.$pattern if( substr($pattern,0,2) eq '.*');
@@ -90,13 +96,13 @@ sub glob {
 	} elsif( $pattern=~ m:/:) {
 		# Too difficult to simulate, so use slow variant
 		my $old=$ENV{PWD};
-		chdir $dir;
-		$pattern=~s/(?<!\\)([^a-zA-Z0-9\*\?])/\\$1/g;
+		CORE::chdir $dir;
+		$pattern=_escape($pattern);
 		@result= eval { CORE::glob($pattern); };
-		chdir $old;
+		CORE::chdir $old;
 	} else {
 		# The fast variant for simple matches
-		$pattern=~s/(?<!\\)([^a-zA-Z0-9\*\?])/\\$1/g;
+		$pattern=_escape($pattern);
 		$pattern=~s/\*/.*/g;
 		$pattern=~s/\?/./g;
 		$pattern='[^\.]'.$pattern if( substr($pattern,0,2) eq '.*');
@@ -113,7 +119,7 @@ sub glob {
 # Looks up the name of a signal
 #
 
-sub signal_name {
+sub fb_signal_name {
 	my $signalnum = shift;
 	my @numbers= split ',',$Config{sig_num};
 	@numbers= split ' ',$Config{sig_num} if( @numbers==1);
@@ -132,7 +138,7 @@ sub signal_name {
 # returns a descriptive name for the POSIX signals
 #
 
-sub signal_description {
+sub fb_signal_description {
 	my $signal_name= signal_name(shift);
 	my $desc= $Psh::text{sig_description}->{$signal_name};
    	if( defined($desc) and $desc) {
@@ -141,6 +147,36 @@ sub signal_description {
 	return "signal $signal_name";
 }
 
+# Return a name for a temp file
+
+sub fb_tmpnam {
+	return POSIX::tmpnam();
+}
+
+sub fb_get_window_size {}
+sub fb_remove_signal_handlers {1}
+sub fb_setup_signal_handlers {1}
+sub fb_setup_sigsegv_handler {1}
+sub fb_setup_readline_handler {1}
+sub fb_reinstall_resize_handler {1}
+sub fb_reap_children {1}
+sub fb_abs_path { undef }
+
+#
+# Exit psh - you won't believe it, but exit needs special treatment on
+# MacOS
+#
+sub fb_exit_psh {
+	Psh::Util::print_debug_class('i',"[Psh::OS::exit_psh() called]\n");
+	Psh::save_history();
+	$ENV{SHELL} = $Psh::old_shell if $Psh::old_shell;
+	CORE::exit($_[0]) if $_[0];
+	CORE::exit(0);
+}
+
+sub fb_getcwd {
+	return Cwd::getcwd();
+}
 
 1;
 
